@@ -3,13 +3,12 @@ import warnings
 from multiprocessing import current_process
 from typing import Tuple
 
-import requests
-
-from lightly.openapi_generated.swagger_client import VersioningApi, VersionNumber
+from lightly.openapi_generated.swagger_client import VersioningApi
 from lightly.openapi_generated.swagger_client.api_client import ApiClient
 
-from lightly.openapi_generated.swagger_client.configuration import Configuration
+import lightly.api.api_workflow_client as api_workflow_client
 from lightly.api.utils import getenv
+from lightly.utils import version_compare
 
 
 class LightlyAPITimeoutException(Exception):
@@ -37,15 +36,22 @@ def do_version_check(current_version: str):
             current_version: str = versioning_api.get_latest_pip_version(
                 current_version=current_version)
             latest_version: str = versioning_api.get_minimum_compatible_pip_version()
-            if version_compare(current_version, latest_version) < 0:
-                # local version is behind latest version
-                pretty_print_latest_version(current_version, latest_version)
+
+            try:
+                if version_compare(current_version, latest_version) < 0:
+                    # local version is behind latest version
+                    pretty_print_latest_version(current_version, latest_version)
+            except ValueError:
+                pass
+                # error during version compare
+                # we just skip the version check
 
 
 
 def get_versioning_api() -> VersioningApi:
-    configuration = Configuration()
-    configuration.host = getenv('LIGHTLY_SERVER_LOCATION', 'https://api.lightly.ai')
+    configuration = api_workflow_client.get_api_client_configuration(
+        raise_if_no_token_specified=False,
+    )
     api_client = ApiClient(configuration=configuration)
     versioning_api = VersioningApi(api_client)
     return versioning_api
@@ -66,20 +72,6 @@ def get_minimum_compatible_version():
     return version_number
 
 
-def version_compare(v0, v1):
-    v0 = [int(n) for n in v0.split('.')][::-1]
-    v1 = [int(n) for n in v1.split('.')][::-1]
-    assert len(v0) == 3
-    assert len(v1) == 3
-    pairs = list(zip(v0, v1))[::-1]
-    for x, y in pairs:
-        if x < y:
-            return -1
-        if x > y:
-            return 1
-    return 0
-
-
 def pretty_print_latest_version(current_version, latest_version, width=70):
     warning = f"You are using lightly version {current_version}. " \
               f"There is a newer version of the package available. " \
