@@ -8,10 +8,13 @@ import warnings
 from typing import Type
 
 import torch
+import hydra
 from hydra import utils
 from torch import nn as nn
 from torch.utils.hipify.hipify_python import bcolors
 
+from lightly.utils import version_compare
+
 from lightly.cli._cli_simclr import _SimCLR
 from lightly.embedding import SelfSupervisedEmbedding
 
@@ -51,6 +54,24 @@ def fix_input_path(path):
     return path
 
 
+def fix_hydra_arguments(config_path: str = 'config', config_name: str = 'config'):
+    """Helper to make hydra arugments adaptive to installed hydra version
+    
+    Hydra introduced the `version_base` argument in version 1.2.0
+    We use this helper to provide backwards compatibility to older hydra verisons.    
+    """
+
+    hydra_args = {'config_path': config_path, 'config_name': config_name}
+
+    try:
+        if version_compare(hydra.__version__, '1.1.2') > 0:
+            hydra_args['version_base'] = '1.1'
+    except ValueError:
+        pass
+    
+    return hydra_args
+
+
 def is_url(checkpoint):
     """Check whether the checkpoint is a url or not.
 
@@ -244,4 +265,4 @@ def get_model_from_config(cfg, is_cli_call: bool = False) -> SelfSupervisedEmbed
         load_from_state_dict(model, state_dict)
 
     encoder = SelfSupervisedEmbedding(model, None, None, None)
-    return encoder
\ No newline at end of file
+    return encoder
