@@ -14,6 +14,7 @@ import torch
 import torch.nn as nn
 import warnings
 
+from omegaconf import OmegaConf
 from torch.utils.hipify.hipify_python import bcolors
 
 from lightly.cli._cli_simclr import _SimCLR
@@ -31,6 +32,7 @@ from lightly.cli._helpers import fix_input_path
 from lightly.cli._helpers import load_state_dict_from_url
 from lightly.cli._helpers import load_from_state_dict
 from lightly.cli._helpers import cpu_count
+from lightly.cli._helpers import fix_hydra_arguments
 
 
 def _train_cli(cfg, is_cli_call=True):
@@ -46,9 +48,6 @@ def _train_cli(cfg, is_cli_call=True):
         torch.backends.cudnn.deterministic = True
         torch.backends.cudnn.benchmark = False
 
-    if cfg["trainer"]["weights_summary"] == "None":
-        cfg["trainer"]["weights_summary"] = None
-
     if torch.cuda.is_available():
         device = 'cuda'
     elif cfg['trainer'] and cfg['trainer']['gpus']:
@@ -132,8 +131,15 @@ def _train_cli(cfg, is_cli_call=True):
                                              collate_fn=collate_fn)
 
     encoder = SelfSupervisedEmbedding(model, criterion, optimizer, dataloader)
-    encoder.init_checkpoint_callback(**cfg['checkpoint_callback'])
-    encoder.train_embedding(**cfg['trainer'], strategy=distributed_strategy)
+    # Add strategy field to trainer config
+    trainer_config = OmegaConf.create(
+        dict(strategy=distributed_strategy, **cfg['trainer'])
+    )
+    encoder.train_embedding(
+        trainer_config=trainer_config,
+        checkpoint_callback_config=cfg['checkpoint_callback'],
+        summary_callback_config=cfg['summary_callback'],
+    )
 
     print(f'Best model is stored at: {bcolors.OKBLUE}{encoder.checkpoint}{bcolors.ENDC}')
     os.environ[
@@ -142,7 +148,7 @@ def _train_cli(cfg, is_cli_call=True):
     return encoder.checkpoint
 
 
-@hydra.main(config_path="config", config_name="config")
+@hydra.main(**fix_hydra_arguments(config_path = 'config', config_name = 'config'))
 def train_cli(cfg):
     """Train a self-supervised model from the command-line.
 
