@@ -7,6 +7,9 @@ from lightly.data.dataset import LightlyDataset
 from lightly.data.collate import BaseCollateFunction
 from lightly.data.collate import DINOCollateFunction
 from lightly.data.collate import ImageCollateFunction
+from lightly.data.collate import MAECollateFunction
+from lightly.data.collate import MSNCollateFunction
+from lightly.data.collate import PIRLCollateFunction
 from lightly.data.collate import SimCLRCollateFunction
 from lightly.data.collate import MoCoCollateFunction
 from lightly.data.collate import MultiCropCollateFunction
@@ -15,4 +18,4 @@ from lightly.data.collate import imagenet_normalize
 from lightly.data._video import VideoError
 from lightly.data._video import EmptyVideoError
 from lightly.data._video import NonIncreasingTimestampError
-from lightly.data._video import UnseekableTimestampError
\ No newline at end of file
+from lightly.data._video import UnseekableTimestampError
