@@ -2,15 +2,16 @@
 
 # Copyright (c) 2020. Lightly AG and its affiliates.
 # All Rights Reserved
-import os
 import copy
+import os
 
+
+import omegaconf
+from omegaconf import DictConfig
 import pytorch_lightning as pl
 import pytorch_lightning.core.lightning as lightning
-from pytorch_lightning.callbacks.model_checkpoint import ModelCheckpoint
-import torch.nn as nn
 
-from lightly.embedding._callback import CustomModelCheckpoint
+from lightly.embedding import callbacks
 
 
 class BaseEmbedding(lightning.LightningModule):
@@ -43,9 +44,6 @@ class BaseEmbedding(lightning.LightningModule):
         self.checkpoint = None
         self.cwd = os.getcwd()
 
-        self.checkpoint_callback = None
-        self.init_checkpoint_callback()
-
     def forward(self, x0, x1):
         return self.model(x0, x1)
 
@@ -70,67 +68,56 @@ class BaseEmbedding(lightning.LightningModule):
     def train_dataloader(self):
         return self.dataloader
 
-    def train_embedding(self, **kwargs):
+    def train_embedding(
+        self,
+        trainer_config: DictConfig,
+        checkpoint_callback_config: DictConfig,
+        summary_callback_config: DictConfig,
+    ):
         """ Train the model on the provided dataset.
 
         Args:
-            **kwargs: pylightning_trainer arguments, examples include:
+            trainer_config: pylightning_trainer arguments, examples include:
                 min_epochs: (int) Minimum number of epochs to train
                 max_epochs: (int) Maximum number of epochs to train
-                gpus: (int) number of gpus to use
-                weights_summary: (str) how to print a summary of the model and weights (number, size)
+                gpus: (int) Number of gpus to use
+                enable_model_summary: (bool) Whether to enable model summarisation.
+                weights_summary: (str) DEPRECATED. How to print a summary of the model and weights.
+            checkpoint_callback_config: ModelCheckpoint callback arguments
+            summary_callback_config: ModelSummary callback arguments
 
         Returns:
             A trained encoder, ready for embedding datasets.
 
         """
+        trainer_callbacks = []
 
-        trainer = pl.Trainer(**kwargs, callbacks=[self.checkpoint_callback])
+        checkpoint_cb = callbacks.create_checkpoint_callback(**checkpoint_callback_config)
+        trainer_callbacks.append(checkpoint_cb)
+
+        summary_cb = callbacks.create_summary_callback(
+            summary_callback_config=summary_callback_config,
+            trainer_config=trainer_config,
+        )
+        if summary_cb is not None:
+            trainer_callbacks.append(summary_cb)
+
+        # Remove weights_summary from trainer_config now that the summary callback
+        # has been created. TODO: Drop support for the "weights_summary" argument.
+        trainer_config_copy = copy.deepcopy(trainer_config)
+        if "weights_summary" in trainer_config_copy:
+            with omegaconf.open_dict(trainer_config_copy):
+                del trainer_config_copy["weights_summary"]
+
+        trainer = pl.Trainer(**trainer_config_copy, callbacks=trainer_callbacks)
 
         trainer.fit(self)
 
-        self.checkpoint = self.checkpoint_callback.best_model_path
-        self.checkpoint = os.path.join(self.cwd, self.checkpoint)
+        if checkpoint_cb.best_model_path != "":
+            self.checkpoint = os.path.join(self.cwd, checkpoint_cb.best_model_path)
 
     def embed(self, *args, **kwargs):
         """Must be implemented by classes which inherit from BaseEmbedding.
 
         """
         raise NotImplementedError()
-
-    def init_checkpoint_callback(self,
-                                 save_last=False,
-                                 save_top_k=0,
-                                 monitor='loss',
-                                 dirpath=None):
-        """Initializes the checkpoint callback.
-
-        Args:
-            save_last:
-                Whether or not to save the checkpoint of the last epoch.
-            save_top_k:
-                Save the top_k model checkpoints.
-            monitor:
-                Which quantity to monitor.
-            dirpath:
-                Where to save the checkpoint.
-
-        """
-
-        if pl.__version__[:3] in ['1.0', '1.1', '1.2']:
-            # initialize custom model checkpoint
-            self.checkpoint_callback = CustomModelCheckpoint()
-            self.checkpoint_callback.save_last = save_last
-            self.checkpoint_callback.save_top_k = save_top_k
-            self.checkpoint_callback.monitor = monitor
-
-            dirpath = self.cwd if dirpath is None else dirpath
-            self.checkpoint_callback.dirpath = dirpath
-        else:
-            self.checkpoint_callback = ModelCheckpoint(
-                dirpath=self.cwd if dirpath is None else dirpath,
-                filename='lightly_epoch_{epoch:d}',
-                save_last=save_last,
-                save_top_k=save_top_k,
-                monitor=monitor,
-                auto_insert_metric_name=False)
